@@ -50,9 +50,10 @@ class Q_DECL_EXPORT PowerDevilUPowerBackend : public PowerDevil::BackendInterfac
 {
     Q_OBJECT
     Q_DISABLE_COPY(PowerDevilUPowerBackend)
+    Q_PLUGIN_METADATA(IID "org.kde.powerdevil.upowerbackend");
 
 public:
-    explicit PowerDevilUPowerBackend(QObject* parent);
+    explicit PowerDevilUPowerBackend(QObject* parent = nullptr);
     virtual ~PowerDevilUPowerBackend();
 
     virtual void init();
@@ -117,6 +118,9 @@ private:
     bool m_lidIsClosed;
     bool m_onBattery;
 
+    // property if brightness control is leds subsystem
+    bool m_isLedBrightnessControl;
+
     //helper path
     QString m_syspath;
 };
